#[non_exhaustive]pub enum DiffEntry {
Added {
path: String,
},
Removed {
path: String,
},
Modified {
path: String,
old_sha256: String,
new_sha256: String,
},
Renamed {
old_path: String,
new_path: String,
},
ModeChanged {
path: String,
old_mode: String,
new_mode: String,
},
SymlinkTargetChanged {
path: String,
old_target: String,
new_target: String,
},
}Expand description
A single change entry produced by diff_snapshots.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Added
File exists in the right snapshot but not the left.
Removed
File exists in the left snapshot but not the right.
Modified
File exists in both snapshots but its content identity changed.
Renamed
File was removed from old_path and appeared at new_path with the
same SHA-256. This is a heuristic: a true rename has identical content.
ModeChanged
File content is unchanged but Unix mode changed.
SymlinkTargetChanged
Symlink exists in both snapshots but points to a different target.