pub fn fmt_snapshot_with_options(
snapshot: &Path,
options: FmtOptions,
) -> Result<String, GitClosureError>Expand description
Reads and canonicalizes a snapshot file with explicit formatting options.
pub fn fmt_snapshot_with_options(
snapshot: &Path,
options: FmtOptions,
) -> Result<String, GitClosureError>Reads and canonicalizes a snapshot file with explicit formatting options.